[PATCH] mailbox: bcm-flexrm-mailbox: Fix typo in dma_mask setup

Anup Patel anup.patel at broadcom.com
Wed May 17 00:54:50 PDT 2017


The output address of Broadcom FlexRM is 39bits and not
40bits hence we fix dma_mask setup in flexrm_mbox_probe()
accordingly.

Fixes: dbc049eee730 ("mailbox: Add driver for Broadcom
FlexRM ring manager")

Signed-off-by: Anup Patel <anup.patel at broadcom.com>
Reviewed-by: Scott Branden <scott.branden at broadcom.com>
---
 drivers/mailbox/bcm-flexrm-mailbox.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/drivers/mailbox/bcm-flexrm-mailbox.c b/drivers/mailbox/bcm-flexrm-mailbox.c
index da67882..6aeac6e 100644
--- a/drivers/mailbox/bcm-flexrm-mailbox.c
+++ b/drivers/mailbox/bcm-flexrm-mailbox.c
@@ -1479,8 +1479,8 @@ static int flexrm_mbox_probe(struct platform_device *pdev)
 		ring->cmpl_read_offset = 0;
 	}
 
-	/* FlexRM is capable of 40-bit physical addresses only */
-	ret = dma_set_mask_and_coherent(dev, DMA_BIT_MASK(40));
+	/* FlexRM is capable of 39-bit physical addresses only */
+	ret = dma_set_mask_and_coherent(dev, DMA_BIT_MASK(39));
 	if (ret) {
 		ret = dma_set_mask_and_coherent(dev, DMA_BIT_MASK(32));
 		if (ret)
-- 
2.7.4




More information about the linux-arm-kernel mailing list